library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

use work.FfpgCorePkg.all;

entity FfpgCoreWrapper is
    generic (
        CLK_FREQ: natural -- input clock frequency in MHz
    );
    port (
        -- Wishbone connection
        rst_n_i: in std_logic;
        clk_sys_i: in std_logic;
        wb_adr_i: in std_logic_vector(31 downto 0);
        wb_dat_i: in std_logic_vector(31 downto 0);
        wb_dat_o: out std_logic_vector(31 downto 0);
        wb_cyc_i: in std_logic;
        wb_sel_i: in std_logic_vector(3 downto 0);
        wb_stb_i: in std_logic;
        wb_we_i: in std_logic;
        wb_ack_o: out std_logic;
        wb_stall_o: out std_logic;
        TriggerDacFrameSynchronization_n: out std_logic;
        TriggerDacSerialClock: out std_logic;
        TriggerDacSerialData: out std_logic;
        VcxoDacFrameSynchronization_n: out std_logic;
        VcxoDacSerialClock: out std_logic;
        VcxoDacSerialData: out std_logic;
        ch1_out_en: out std_logic;
        ch2_out_en: out std_logic
    );
end entity;

architecture syn of FfpgCoreWrapper is

    signal TriggerDac_o: t_FfpgAd5600Interface;
    signal VcxoDac_o: t_FfpgAd5600Interface;
    
begin

    cFfpgCore: entity work.FfpgCore(syn)
        generic map (
            CLK_FREQ => CLK_FREQ
        )
        port map (
            rst_n_i => rst_n_i,
            clk_sys_i => clk_sys_i,
            wb_adr_i => wb_adr_i,
            wb_dat_i => wb_dat_i,
            wb_dat_o => wb_dat_o,
            wb_cyc_i => wb_cyc_i,
            wb_sel_i => wb_sel_i,
            wb_stb_i => wb_stb_i,
            wb_we_i => wb_we_i,
            wb_ack_o => wb_ack_o,
            wb_stall_o => wb_stall_o,
            TriggerDac_o => TriggerDac_o,
            VcxoDac_o => VcxoDac_o,
            ch1_out_en => ch1_out_en,
            ch2_out_en => ch2_out_en
        );

        TriggerDacFrameSynchronization_n <= TriggerDac_o.FrameSynchronization_n;
        TriggerDacSerialClock <= TriggerDac_o.SerialClock;
        TriggerDacSerialData <= TriggerDac_o.SerialData;
        VcxoDacFrameSynchronization_n <= VcxoDac_o.FrameSynchronization_n;
        VcxoDacSerialClock <= VcxoDac_o.SerialClock;
        VcxoDacSerialData <= VcxoDac_o.SerialData;
end architecture;
