`include "Config.svh"

import uvm_pkg::*;
import Ad5600Package::*;
import TestbenchPackage::*;

module Testbench;

    timeunit 1ns;
    
    parameter CLK_PERIOD = 1000/`CLK_FREQ;
    
    bit clk, reset;
    bit wb_ack;

    FFPGInterface LocalInterface(clk, reset);

    FfpgCoreWrapper #(
        .CLK_FREQ(200)
    ) dut (
        .rst_n_i(~reset),
        .clk_sys_i(clk),
        .wb_adr_i(LocalInterface.Wb.adr),
        .wb_dat_i(LocalInterface.Wb.dat_o),
        .wb_dat_o(LocalInterface.Wb.dat_i),
        .wb_cyc_i(LocalInterface.Wb.cyc),
        .wb_sel_i(LocalInterface.Wb.sel),
        .wb_stb_i(LocalInterface.Wb.stb),
        .wb_we_i(LocalInterface.Wb.we),
        .wb_ack_o(wb_ack),
        .wb_stall_o(), // doesn't exist in B3 version of WB
        .TriggerDacFrameSynchronization_n(LocalInterface.TriggerDac.FrameSynchronization_n),
        .TriggerDacSerialClock(LocalInterface.TriggerDac.SerialClock),
        .TriggerDacSerialData(LocalInterface.TriggerDac.SerialData),
        .VcxoDacFrameSynchronization_n(LocalInterface.VcxoDac.FrameSynchronization_n),
        .VcxoDacSerialClock(LocalInterface.VcxoDac.SerialClock),
        .VcxoDacSerialData(LocalInterface.VcxoDac.SerialData),
        .ch1_out_en(), // not tested so far
        .ch2_out_en() // not tested so far
    );
    
    initial begin: unusedWbSignals
        LocalInterface.Wb.err = 0;
        LocalInterface.Wb.rty = 0;
    end
    assign LocalInterface.Wb.ack = wb_ack;

    initial begin: clockGenerator
        clk = 0;
        forever #(CLK_PERIOD/2) clk = ~clk;
    end

    initial begin: resetGenerator
        reset = 1;
        repeat(3) @(negedge clk);
        reset = 0;
    end
    assign LocalInterface.Wb.rst_i = reset;

    initial begin: mainTest
        uvm_config_db #(virtual FFPGInterface)::set(null, "uvm_test_top.*", "dut_vi", LocalInterface);
        uvm_top.finish_on_completion = 0; // not to finish when GUI is used
        run_test("TestTriggerAdc");
        $stop();
    end
    
    initial begin: timeout
        #100us $error("Simulation timeout!");
        $stop();
    end

endmodule